@@ -15,6 +15,9 @@ if __name__ == '__main__':
     '--with-hwloc=1',
     '--with-hypre-include=/usr/include/hypre',
     '--with-hypre-lib=/usr/lib/libHYPRE.so',
+    '--with-kokkos-include=/usr/include/kokkos',
+    '--with-kokkos-lib=libkokkoscore.so',
+    '--with-kokkos=1',
     '--with-libjpeg=1',
     '--with-metis=1',
     '--with-mpi-dir=/usr',
@@ -33,13 +36,15 @@ if __name__ == '__main__':
     '--with-superlu-lib=-lsuperlu',
     '--with-superlu_dist-include=/usr/include/superlu_dist',
     '--with-superlu_dist-lib=-lsuperlu_dist',
+    '--with-triangle=1',
     '--with-yaml=1',
     '--with-zfp=1',
-    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -flto=auto',
-    'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -flto=auto',
-    'FFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt         -Wp,-D_FORTIFY_SOURCE=3 -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer',
+    '--with-zoltan=1',
+    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/petsc/src=/usr/src/debug/petsc -flto=auto',
+    'CXXFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat -Werror=format-security         -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -Wp,-D_GLIBCXX_ASSERTIONS -g -ffile-prefix-map=/build/petsc/src=/usr/src/debug/petsc -flto=auto',
+    'FFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt         -Wp,-D_FORTIFY_SOURCE=3 -fstack-clash-protection -fcf-protection         -fno-omit-frame-pointer -mno-omit-leaf-frame-pointer -g -ffile-prefix-map=/build/petsc/src=/usr/src/debug/petsc',
     'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now          -Wl,-z,pack-relative-relocs -flto=auto -lstdc++',
-    'MAKEFLAGS=-j4',
+    'MAKEFLAGS=-j32',
     'PETSC_ARCH=linux-c-opt',
   ]
   configure.petsc_configure(configure_options)
